# coding=utf-8
from unittest import TestCase

from earthdiagnostics.statistics.climatologicalpercentile import ClimatologicalPercentile
from earthdiagnostics.diagnostic import DiagnosticVariableOption
from mock import Mock, patch

from earthdiagnostics.modelingrealm import ModelingRealms


class TestClimatologicalPercentile(TestCase):

    def setUp(self):
        self.data_manager = Mock()
        self.data_manager.variable_list.get_variable.return_value = None

        self.diags = Mock()
        self.diags.data_manager = self.data_manager

    def fake_parse(self, value):
        return value

    @patch.object(DiagnosticVariableOption, 'parse', fake_parse)
    def test_generate_jobs(self):
        jobs = ClimatologicalPercentile.generate_jobs(self.diags, ['climpercent', 'ocean', 'var', '2000', '2001', '11'])
        self.assertEqual(len(jobs), 1)
        self.assertEqual(jobs[0], ClimatologicalPercentile(self.data_manager, ModelingRealms.ocean, 'var',
                                                           2000, 2000, 2001, float('nan'), float('nan'), 11,
                                                           self.diags.config.experiment))

        jobs = ClimatologicalPercentile.generate_jobs(self.diags, ['climpercent', 'ocean', 'var', '2000', '2001', '11',
                                                                   '', '0', '40'])
        self.assertEqual(len(jobs), 1)
        self.assertEqual(jobs[0], ClimatologicalPercentile(self.data_manager, ModelingRealms.ocean, 'var',
                                                           2000, 2000, 2001, 0.0, 40.0, 11,
                                                           self.diags.config.experiment))

        jobs = ClimatologicalPercentile.generate_jobs(self.diags, ['climpercent', 'ocean', 'var', '2000', '2001', '7',
                                                                   '1000', '', '10'])
        self.assertEqual(len(jobs), 1)
        self.assertEqual(jobs[0], ClimatologicalPercentile(self.data_manager, ModelingRealms.ocean, 'var',
                                                           1000, 2000, 2001, float('nan'), 10.0, 7,
                                                           self.diags.config.experiment))

        with self.assertRaises(Exception):
            ClimatologicalPercentile.generate_jobs(self.diags, ['climpercent'])
        with self.assertRaises(Exception):
            ClimatologicalPercentile.generate_jobs(self.diags, ['climpercent', '0', '0', '0', '0', '0', '0', '0', '0'])

    def test_str(self):
        diagnostic = ClimatologicalPercentile(self.data_manager, ModelingRealms.ocean, 'var',
                                                   1000, 2000, 2001, float('nan'), float('nan'), 11,
                                                   self.diags.config.experiment)

        self.assertEquals(str(diagnostic), 'Climatological percentile Variable: ocean:var Period: 2000-2001 '
                                           'Forecast month: 11 Bins: 1000')
